Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Amplify.

Actions, resources, and condition keys for AWS Amplify - Service Authorization Reference

# Actions, resources, and condition keys for AWS Amplify

AWS Amplify (service prefix: `amplify` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS Amplify
- Resource types defined by AWS Amplify
- Condition keys for AWS Amplify

## Actions defined by AWS Amplify

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateApp | Grants permission to create a new Amplify App | Write | apps* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateBackendEnvironment | Grants permission to create a new backend environment for an Amplify App | Write | apps* |  |
CreateBranch | Grants permission to create a new Branch for an Amplify App | Write | apps* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateDeployment | Grants permission to create a deployment for manual deploy apps. (Apps are not connected to repository) | Write | branches* |  |
CreateDomainAssociation | Grants permission to create a new DomainAssociation on an App | Write | apps* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateWebHook | Grants permission to create a new webhook on an App | Write | branches* |  |
DeleteApp | Grants permission to delete an existing Amplify App by appId | Write | apps* |  |
DeleteBackendEnvironment | Grants permission to delete a branch for an Amplify App | Write | apps* |  |
DeleteBranch | Grants permission to delete a branch for an Amplify App | Write | branches* |  |
DeleteDomainAssociation | Grants permission to delete a DomainAssociation | Write | domains* |  |
DeleteJob | Grants permission to delete a job, for an Amplify branch, part of Amplify App | Write | jobs* |  |
DeleteWebHook | Grants permission to delete a webhook by id | Write | webhooks* |  |
GenerateAccessLogs | Grants permission to generate website access logs for a specific time range via a pre-signed URL | Write | apps* |  |
GetApp | Grants permission to retrieve an existing Amplify App by appId | Read | apps* |  |
GetArtifactUrl | Grants permission to retrieve artifact info that corresponds to a artifactId | Read | apps* |  |
GetBackendEnvironment | Grants permission to retrieve a backend environment for an Amplify App | Read | apps* |  |
GetBranch | Grants permission to retrieve a branch for an Amplify App | Read | branches* |  |
GetDomainAssociation | Grants permission to retrieve domain info that corresponds to an appId and domainName | Read | domains* |  |
GetJob | Grants permission to get a job for a branch, part of an Amplify App | Read | jobs* |  |
GetWebHook | Grants permission to retrieve webhook info that corresponds to a webhookId | Read | webhooks* |  |
ListApps | Grants permission to list existing Amplify Apps | List |  |  |
ListArtifacts | Grants permission to list artifacts with an app, a branch, a job and an artifact type | List | apps* |  |
ListBackendEnvironments | Grants permission to list backend environments for an Amplify App | List | apps* |  |
ListBranches | Grants permission to list branches for an Amplify App | List | apps* |  |
ListDomainAssociations | Grants permission to list domains with an app | List | apps* |  |
ListJobs | Grants permission to list Jobs for a branch, part of an Amplify App | List | branches* |  |
ListTagsForResource | Grants permission to list tags for an AWS Amplify Console resource | Read | apps |  |
branches |  |
domains |  |
webhooks |  |
ListWebHooks | Grants permission to list webhooks on an App | List | apps* |  |
StartDeployment | Grants permission to start a deployment for manual deploy apps. (Apps are not connected to repository) | Write | branches* |  |
StartJob | Grants permission to start a new job for a branch, part of an Amplify App | Write | jobs* |  |
StopJob | Grants permission to stop a job that is in progress, for an Amplify branch, part of Amplify App | Write | jobs* |  |
TagResource | Grants permission to tag an AWS Amplify Console resource | Tagging | apps |  |
branches |  |
domains |  |
webhooks |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Grants permission to remove a tag from an AWS Amplify Console resource | Tagging | apps |  |
branches |  |
domains |  |
webhooks |  |
| aws:TagKeys |
UpdateApp | Grants permission to update an existing Amplify App | Write | apps* |  |
UpdateBranch | Grants permission to update a branch for an Amplify App | Write | branches* |  |
UpdateDomainAssociation | Grants permission to update a DomainAssociation on an App | Write | domains* |  |
UpdateWebHook | Grants permission to update a webhook | Write | webhooks* |  |

## Resource types defined by AWS Amplify

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
apps | `arn:$ { Partition}:amplify:$ { Region}:$ { Account}:apps/$ { AppId}` | aws:ResourceTag/${TagKey}
branches | `arn:$ { Partition}:amplify:$ { Region}:$ { Account}:apps/$ { AppId}/branches/$ { BranchName}` | aws:ResourceTag/${TagKey}
jobs | `arn:$ { Partition}:amplify:$ { Region}:$ { Account}:apps/$ { AppId}/branches/$ { BranchName}/jobs/$ { JobId}` |
domains | `arn:$ { Partition}:amplify:$ { Region}:$ { Account}:apps/$ { AppId}/domains/$ { DomainName}` | aws:ResourceTag/${TagKey}
webhooks | `arn:$ { Partition}:amplify:$ { Region}:$ { Account}:webhooks/$ { WebhookId}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS Amplify

AWS Amplify defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by a tag's key and value in a request | String
aws:ResourceTag/${TagKey} | Filters access by a tag's key associated with the resource | String
aws:TagKeys | Filters access by the tag keys in a request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.